Architecture
============

Host
----

.. autoclass:: nuka.hosts.base.BaseHost
   :members:

Task
-----

.. autoclass:: nuka.task.Task
   :members:

Remote task
------------

.. autoclass:: nuka.remote.task.Task
   :members: sh, do, is_alive, send_progress, send_log
